@@ -16,7 +16,7 @@ static const u32   DGST_POS1      = 1;
 static const u32   DGST_POS2      = 2;
 static const u32   DGST_POS3      = 3;
 static const u32   DGST_SIZE      = DGST_SIZE_4_32;
-static const u32   HASH_CATEGORY  = HASH_CATEGORY_GENERIC_KDF;
+static const u32   HASH_CATEGORY  = HASH_CATEGORY_FRAMEWORK;
 static const char *HASH_NAME      = "Python passlib pbkdf2-sha1";
 static const u64   KERN_TYPE      = 12000;
 static const u32   OPTI_TYPE      = OPTI_TYPE_ZERO_BYTE
