@@ -1261,9 +1261,10 @@ u64 status_get_progress_cur (const hashcat_ctx_t *hashcat_ctx)
 
 u64 status_get_progress_ignore (const hashcat_ctx_t *hashcat_ctx)
 {
-  const hashes_t       *hashes        = hashcat_ctx->hashes;
-  const status_ctx_t   *status_ctx    = hashcat_ctx->status_ctx;
-  const user_options_t *user_options  = hashcat_ctx->user_options;
+  const hashes_t             *hashes             = hashcat_ctx->hashes;
+  const status_ctx_t         *status_ctx         = hashcat_ctx->status_ctx;
+  const user_options_t       *user_options       = hashcat_ctx->user_options;
+  const user_options_extra_t *user_options_extra = hashcat_ctx->user_options_extra;
 
   if (user_options->attack_mode == ATTACK_MODE_ASSOCIATION)
   {
@@ -1273,6 +1274,27 @@ u64 status_get_progress_ignore (const hashcat_ctx_t *hashcat_ctx)
     return 0;
   }
 
+  u64 words_cnt = status_ctx->words_cnt;
+
+  if (user_options->limit)
+  {
+    const combinator_ctx_t *combinator_ctx = hashcat_ctx->combinator_ctx;
+    const mask_ctx_t       *mask_ctx       = hashcat_ctx->mask_ctx;
+    const straight_ctx_t   *straight_ctx   = hashcat_ctx->straight_ctx;
+
+    words_cnt = MIN (user_options->limit, status_ctx->words_base);
+
+    if (user_options->slow_candidates == true)
+    {
+      // nothing to do
+    }
+    else
+    {
+      if      (user_options_extra->attack_kern == ATTACK_KERN_STRAIGHT) words_cnt  *= straight_ctx->kernel_rules_cnt;
+      else if (user_options_extra->attack_kern == ATTACK_KERN_COMBI)    words_cnt  *= combinator_ctx->combs_cnt;
+      else if (user_options_extra->attack_kern == ATTACK_KERN_BF)       words_cnt  *= mask_ctx->bfs_cnt;
+    }
+  }
   // Important for ETA only
 
   u64 progress_ignore = 0;
@@ -1285,7 +1307,7 @@ u64 status_get_progress_ignore (const hashcat_ctx_t *hashcat_ctx)
                     + status_ctx->words_progress_rejected[salt_pos]
                     + status_ctx->words_progress_restored[salt_pos];
 
-      const u64 left = status_ctx->words_cnt - all;
+      const u64 left = words_cnt - all;
 
       progress_ignore += left;
     }
@@ -1556,7 +1578,7 @@ int status_get_cpt_cur_min (const hashcat_ctx_t *hashcat_ctx)
 
   for (int i = 0; i < CPT_CACHE; i++)
   {
-    const u32       cracked   = cpt_ctx->cpt_buf[i].cracked;
+    const u32    cracked   = cpt_ctx->cpt_buf[i].cracked;
     const time_t timestamp = cpt_ctx->cpt_buf[i].timestamp;
 
     if ((timestamp + 60) > now)
@@ -1581,7 +1603,7 @@ int status_get_cpt_cur_hour (const hashcat_ctx_t *hashcat_ctx)
 
   for (int i = 0; i < CPT_CACHE; i++)
   {
-    const u32       cracked   = cpt_ctx->cpt_buf[i].cracked;
+    const u32    cracked   = cpt_ctx->cpt_buf[i].cracked;
     const time_t timestamp = cpt_ctx->cpt_buf[i].timestamp;
 
     if ((timestamp + 3600) > now)
@@ -1606,7 +1628,7 @@ int status_get_cpt_cur_day (const hashcat_ctx_t *hashcat_ctx)
 
   for (int i = 0; i < CPT_CACHE; i++)
   {
-    const u32       cracked   = cpt_ctx->cpt_buf[i].cracked;
+    const u32    cracked   = cpt_ctx->cpt_buf[i].cracked;
     const time_t timestamp = cpt_ctx->cpt_buf[i].timestamp;
 
     if ((timestamp + 86400) > now)
@@ -1618,37 +1640,58 @@ int status_get_cpt_cur_day (const hashcat_ctx_t *hashcat_ctx)
   return cpt_cur_day;
 }
 
-int status_get_cpt_avg_min (const hashcat_ctx_t *hashcat_ctx)
+double status_get_cpt_avg_min (const hashcat_ctx_t *hashcat_ctx)
 {
   const cpt_ctx_t *cpt_ctx = hashcat_ctx->cpt_ctx;
 
   const double msec_real = status_get_msec_real (hashcat_ctx);
 
-  const double cpt_avg_min = (double) cpt_ctx->cpt_total / ((msec_real / 1000) / 60);
+  const double min_real = (msec_real / 1000) / 60;
 
-  return (int) cpt_avg_min;
+  double cpt_avg_min = 0;
+
+  if (min_real > 1)
+  {
+    cpt_avg_min = (double) cpt_ctx->cpt_total / min_real;
+  }
+
+  return cpt_avg_min;
 }
 
-int status_get_cpt_avg_hour (const hashcat_ctx_t *hashcat_ctx)
+double status_get_cpt_avg_hour (const hashcat_ctx_t *hashcat_ctx)
 {
   const cpt_ctx_t *cpt_ctx = hashcat_ctx->cpt_ctx;
 
   const double msec_real = status_get_msec_real (hashcat_ctx);
 
-  const double cpt_avg_hour = (double) cpt_ctx->cpt_total / ((msec_real / 1000) / 3600);
+  const double hour_real = (msec_real / 1000) / (60 * 60);
 
-  return (int) cpt_avg_hour;
+  double cpt_avg_hour = 0;
+
+  if (hour_real > 1)
+  {
+    cpt_avg_hour = (double) cpt_ctx->cpt_total / hour_real;
+  }
+
+  return cpt_avg_hour;
 }
 
-int status_get_cpt_avg_day (const hashcat_ctx_t *hashcat_ctx)
+double status_get_cpt_avg_day (const hashcat_ctx_t *hashcat_ctx)
 {
   const cpt_ctx_t *cpt_ctx = hashcat_ctx->cpt_ctx;
 
   const double msec_real = status_get_msec_real (hashcat_ctx);
 
-  const double cpt_avg_day = (double) cpt_ctx->cpt_total / ((msec_real / 1000) / 86400);
+  const double day_real = (msec_real / 1000) / (60 * 60 * 24);
 
-  return (int) cpt_avg_day;
+  double cpt_avg_day = 0;
+
+  if (day_real > 1)
+  {
+    cpt_avg_day = (double) cpt_ctx->cpt_total / day_real;
+  }
+
+  return cpt_avg_day;
 }
 
 char *status_get_cpt (const hashcat_ctx_t *hashcat_ctx)
@@ -1663,13 +1706,13 @@ char *status_get_cpt (const hashcat_ctx_t *hashcat_ctx)
   const int cpt_cur_hour = status_get_cpt_cur_hour (hashcat_ctx);
   const int cpt_cur_day  = status_get_cpt_cur_day  (hashcat_ctx);
 
-  const int cpt_avg_min  = status_get_cpt_avg_min  (hashcat_ctx);
-  const int cpt_avg_hour = status_get_cpt_avg_hour (hashcat_ctx);
-  const int cpt_avg_day  = status_get_cpt_avg_day  (hashcat_ctx);
+  const double cpt_avg_min  = status_get_cpt_avg_min  (hashcat_ctx);
+  const double cpt_avg_hour = status_get_cpt_avg_hour (hashcat_ctx);
+  const double cpt_avg_day  = status_get_cpt_avg_day  (hashcat_ctx);
 
-  if ((cpt_ctx->cpt_start + 86400) < now)
+  if ((cpt_ctx->cpt_start + (60 * 60 * 24)) < now)
   {
-    hc_asprintf (&cpt, "CUR:%d,%d,%d AVG:%d,%d,%d (Min,Hour,Day)",
+    hc_asprintf (&cpt, "CUR:%d,%d,%d AVG:%.2f,%.2f,%.2f (Min,Hour,Day)",
       cpt_cur_min,
       cpt_cur_hour,
       cpt_cur_day,
@@ -1677,29 +1720,23 @@ char *status_get_cpt (const hashcat_ctx_t *hashcat_ctx)
       cpt_avg_hour,
       cpt_avg_day);
   }
-  else if ((cpt_ctx->cpt_start + 3600) < now)
+  else if ((cpt_ctx->cpt_start + (60 * 60)) < now)
   {
-    hc_asprintf (&cpt, "CUR:%d,%d,N/A AVG:%d,%d,%d (Min,Hour,Day)",
+    hc_asprintf (&cpt, "CUR:%d,%d,N/A AVG:%.2f,%.2f,N/a (Min,Hour,Day)",
       cpt_cur_min,
       cpt_cur_hour,
       cpt_avg_min,
-      cpt_avg_hour,
-      cpt_avg_day);
+      cpt_avg_hour);
   }
   else if ((cpt_ctx->cpt_start + 60) < now)
   {
-    hc_asprintf (&cpt, "CUR:%d,N/A,N/A AVG:%d,%d,%d (Min,Hour,Day)",
+    hc_asprintf (&cpt, "CUR:%d,N/A,N/A AVG:%.2f,N/A,N/A (Min,Hour,Day)",
       cpt_cur_min,
-      cpt_avg_min,
-      cpt_avg_hour,
-      cpt_avg_day);
+      cpt_avg_min);
   }
   else
   {
-    hc_asprintf (&cpt, "CUR:N/A,N/A,N/A AVG:%d,%d,%d (Min,Hour,Day)",
-      cpt_avg_min,
-      cpt_avg_hour,
-      cpt_avg_day);
+    hc_asprintf (&cpt, "CUR:N/A,N/A,N/A AVG:N/A,N/A,N/A (Min,Hour,Day)");
   }
 
   return cpt;
@@ -1959,6 +1996,23 @@ char *status_get_brain_link_send_bytes_sec_dev (const hashcat_ctx_t *hashcat_ctx
 }
 #endif
 
+#if defined(__APPLE__)
+char *status_get_hwmon_fan_dev (const hashcat_ctx_t *hashcat_ctx)
+{
+  status_ctx_t *status_ctx = hashcat_ctx->status_ctx;
+
+  char *fanspeed_str = (char *) hcmalloc (HCBUFSIZ_TINY);
+
+  hc_thread_mutex_lock (status_ctx->mux_hwmon);
+
+  hm_get_fanspeed_apple ((hashcat_ctx_t *) hashcat_ctx, fanspeed_str);
+
+  hc_thread_mutex_unlock (status_ctx->mux_hwmon);
+
+  return fanspeed_str;
+}
+#endif
+
 char *status_get_hwmon_dev (const hashcat_ctx_t *hashcat_ctx, const int backend_devices_idx)
 {
   const backend_ctx_t *backend_ctx = hashcat_ctx->backend_ctx;
@@ -2253,6 +2307,10 @@ void status_status_destroy (hashcat_ctx_t *hashcat_ctx, hashcat_status_t *hashca
   hcfree (hashcat_status->guess_mod);
   hcfree (hashcat_status->guess_charset);
   hcfree (hashcat_status->cpt);
+  #ifdef WITH_BRAIN
+  hcfree (hashcat_status->brain_rx_all);
+  hcfree (hashcat_status->brain_tx_all);
+  #endif
 
   hashcat_status->hash_target             = NULL;
   hashcat_status->hash_name               = NULL;
@@ -2266,6 +2324,10 @@ void status_status_destroy (hashcat_ctx_t *hashcat_ctx, hashcat_status_t *hashca
   hashcat_status->guess_mod               = NULL;
   hashcat_status->guess_charset           = NULL;
   hashcat_status->cpt                     = NULL;
+  #ifdef WITH_BRAIN
+  hashcat_status->brain_rx_all            = NULL;
+  hashcat_status->brain_tx_all            = NULL;
+  #endif
 
   for (int device_id = 0; device_id < hashcat_status->device_info_cnt; device_id++)
   {
