@@ -14,6 +14,7 @@
 #include "hwmon.h"
 #include "interface.h"
 #include "hashcat.h"
+#include "timer.h"
 #include "terminal.h"
 
 static const size_t TERMINAL_LINE_LENGTH = 79;
@@ -32,11 +33,16 @@ void welcome_screen (hashcat_ctx_t *hashcat_ctx, const char *version_tag)
   if (user_options->left        == true) return;
   if (user_options->identify    == true) return;
 
-  if (user_options->benchmark == true)
+  if (user_options->usage == true)
+  {
+    event_log_info (hashcat_ctx, "%s (%s) starting in help mode", PROGNAME, version_tag);
+    event_log_info (hashcat_ctx, NULL);
+  }
+  else if (user_options->benchmark == true)
   {
     if (user_options->machine_readable == false)
     {
-      event_log_info (hashcat_ctx, "%s (%s) starting in benchmark mode...", PROGNAME, version_tag);
+      event_log_info (hashcat_ctx, "%s (%s) starting in benchmark mode", PROGNAME, version_tag);
 
       event_log_info (hashcat_ctx, NULL);
 
@@ -56,32 +62,37 @@ void welcome_screen (hashcat_ctx_t *hashcat_ctx, const char *version_tag)
   }
   else if (user_options->restore == true)
   {
-    event_log_info (hashcat_ctx, "%s (%s) starting in restore mode...", PROGNAME, version_tag);
+    event_log_info (hashcat_ctx, "%s (%s) starting in restore mode", PROGNAME, version_tag);
     event_log_info (hashcat_ctx, NULL);
   }
   else if (user_options->speed_only == true)
   {
-    event_log_info (hashcat_ctx, "%s (%s) starting in speed-only mode...", PROGNAME, version_tag);
+    event_log_info (hashcat_ctx, "%s (%s) starting in speed-only mode", PROGNAME, version_tag);
     event_log_info (hashcat_ctx, NULL);
   }
   else if (user_options->progress_only == true)
   {
-    event_log_info (hashcat_ctx, "%s (%s) starting in progress-only mode...", PROGNAME, version_tag);
+    event_log_info (hashcat_ctx, "%s (%s) starting in progress-only mode", PROGNAME, version_tag);
     event_log_info (hashcat_ctx, NULL);
   }
   else if (user_options->backend_info == true)
   {
-    event_log_info (hashcat_ctx, "%s (%s) starting in backend information mode...", PROGNAME, version_tag);
+    event_log_info (hashcat_ctx, "%s (%s) starting in backend information mode", PROGNAME, version_tag);
     event_log_info (hashcat_ctx, NULL);
   }
   else if (user_options->hash_mode_chgd == false)
   {
-    event_log_info (hashcat_ctx, "%s (%s) starting in autodetect mode...", PROGNAME, version_tag);
+    event_log_info (hashcat_ctx, "%s (%s) starting in autodetect mode", PROGNAME, version_tag);
+    event_log_info (hashcat_ctx, NULL);
+  }
+  else if (user_options->hash_info == true)
+  {
+    event_log_info (hashcat_ctx, "%s (%s) starting in hash-info mode", PROGNAME, version_tag);
     event_log_info (hashcat_ctx, NULL);
   }
   else
   {
-    event_log_info (hashcat_ctx, "%s (%s) starting...", PROGNAME, version_tag);
+    event_log_info (hashcat_ctx, "%s (%s) starting", PROGNAME, version_tag);
     event_log_info (hashcat_ctx, NULL);
   }
 
@@ -90,6 +101,7 @@ void welcome_screen (hashcat_ctx_t *hashcat_ctx, const char *version_tag)
     event_log_warning (hashcat_ctx, "You have enabled --force to bypass dangerous warnings and errors!");
     event_log_warning (hashcat_ctx, "This can hide serious problems and should only be done when debugging.");
     event_log_warning (hashcat_ctx, "Do not report hashcat issues encountered when using --force.");
+    event_log_warning (hashcat_ctx, NULL);
   }
 }
 
@@ -249,11 +261,24 @@ static void keypress (hashcat_ctx_t *hashcat_ctx)
         {
           event_log_info (hashcat_ctx, NULL);
 
+          time_t now;
+
+          time (&now);
+
           SuspendThreads (hashcat_ctx);
 
           if (status_ctx->devices_status == STATUS_PAUSED)
           {
-            event_log_info (hashcat_ctx, "Paused");
+            char buf[32] = { 0 };
+
+            char *pause_time = ctime_r (&now, buf);
+
+            const size_t pause_time_len = strlen (pause_time);
+
+            if (pause_time[pause_time_len - 1] == '\n') pause_time[pause_time_len - 1] = 0;
+            if (pause_time[pause_time_len - 2] == '\r') pause_time[pause_time_len - 2] = 0;
+
+            event_log_info (hashcat_ctx, "Paused at %s", pause_time);
           }
 
           event_log_info (hashcat_ctx, NULL);
@@ -269,11 +294,39 @@ static void keypress (hashcat_ctx_t *hashcat_ctx)
         {
           event_log_info (hashcat_ctx, NULL);
 
+          time_t now;
+
+          time (&now);
+
+          const double msec_paused = hc_timer_get (status_ctx->timer_paused);
+
           ResumeThreads (hashcat_ctx);
 
           if (status_ctx->devices_status != STATUS_PAUSED)
           {
-            event_log_info (hashcat_ctx, "Resumed");
+            char buf[32] = { 0 };
+
+            char *resume_time = ctime_r (&now, buf);
+
+            const size_t resume_time_len = strlen (resume_time);
+
+            if (resume_time[resume_time_len - 1] == '\n') resume_time[resume_time_len - 1] = 0;
+            if (resume_time[resume_time_len - 2] == '\r') resume_time[resume_time_len - 2] = 0;
+
+            struct tm *tmp;
+            struct tm  tm;
+
+            time_t sec_run = msec_paused / 1000;
+
+            tmp = gmtime_r (&sec_run, &tm);
+
+            char *display_pause = (char *) hcmalloc (HCBUFSIZ_TINY);
+
+            format_timer_display (tmp, display_pause, HCBUFSIZ_TINY);
+
+            event_log_info (hashcat_ctx, "Resumed at %s (paused for %s)", resume_time, display_pause);
+
+            hcfree (display_pause);
           }
 
           event_log_info (hashcat_ctx, NULL);
@@ -625,7 +678,7 @@ void hash_info_single (hashcat_ctx_t *hashcat_ctx, user_options_t *user_options)
 
       if (need_hexify ((const u8 *) hashconfig->st_pass, strlen (hashconfig->st_pass), user_options->separator, false))
       {
-        char tmp_buf[HCBUFSIZ_LARGE] = { 0 };
+        char *tmp_buf = (char *) hcmalloc (HCBUFSIZ_LARGE);
 
         int tmp_len = 0;
 
@@ -643,6 +696,8 @@ void hash_info_single (hashcat_ctx_t *hashcat_ctx, user_options_t *user_options)
         tmp_buf[tmp_len++] = 0;
 
         event_log_info (hashcat_ctx, "  Example.Pass........: %s", tmp_buf);
+
+        hcfree (tmp_buf);
       }
       else
       {
@@ -731,6 +786,10 @@ void backend_info (hashcat_ctx_t *hashcat_ctx)
       u32   device_maxclock_frequency = device_param->device_maxclock_frequency;
       u64   device_available_mem      = device_param->device_available_mem;
       u64   device_global_mem         = device_param->device_global_mem;
+      u8    pcie_domain               = device_param->pcie_domain;
+      u8    pcie_bus                  = device_param->pcie_bus;
+      u8    pcie_device               = device_param->pcie_device;
+      u8    pcie_function             = device_param->pcie_function;
 
       if (device_param->device_id_alias_cnt)
       {
@@ -746,6 +805,55 @@ void backend_info (hashcat_ctx_t *hashcat_ctx)
       event_log_info (hashcat_ctx, "  Clock..........: %u", device_maxclock_frequency);
       event_log_info (hashcat_ctx, "  Memory.Total...: %" PRIu64 " MB", device_global_mem / 1024 / 1024);
       event_log_info (hashcat_ctx, "  Memory.Free....: %" PRIu64 " MB", device_available_mem / 1024 / 1024);
+      event_log_info (hashcat_ctx, "  PCI.Addr.BDFe..: %04x:%02x:%02x.%d", (u16) pcie_domain, pcie_bus, pcie_device, pcie_function);
+      event_log_info (hashcat_ctx, NULL);
+    }
+  }
+
+  if (backend_ctx->hip)
+  {
+    event_log_info (hashcat_ctx, "HIP Info:");
+    event_log_info (hashcat_ctx, "=========");
+    event_log_info (hashcat_ctx, NULL);
+
+    int hip_devices_cnt    = backend_ctx->hip_devices_cnt;
+    int hip_driver_version = backend_ctx->hip_driver_version;
+
+    event_log_info (hashcat_ctx, "HIP.Version.: %d.%d", hip_driver_version / 1000, (hip_driver_version % 100) / 10);
+    event_log_info (hashcat_ctx, NULL);
+
+    for (int hip_devices_idx = 0; hip_devices_idx < hip_devices_cnt; hip_devices_idx++)
+    {
+      const int backend_devices_idx = backend_ctx->backend_device_from_hip[hip_devices_idx];
+
+      const hc_device_param_t *device_param = backend_ctx->devices_param + backend_devices_idx;
+
+      int   device_id                 = device_param->device_id;
+      char *device_name               = device_param->device_name;
+      u32   device_processors         = device_param->device_processors;
+      u32   device_maxclock_frequency = device_param->device_maxclock_frequency;
+      u64   device_available_mem      = device_param->device_available_mem;
+      u64   device_global_mem         = device_param->device_global_mem;
+      u8    pcie_domain               = device_param->pcie_domain;
+      u8    pcie_bus                  = device_param->pcie_bus;
+      u8    pcie_device               = device_param->pcie_device;
+      u8    pcie_function             = device_param->pcie_function;
+
+      if (device_param->device_id_alias_cnt)
+      {
+        event_log_info (hashcat_ctx, "Backend Device ID #%d (Alias: #%d)", device_id + 1, device_param->device_id_alias_buf[0] + 1);
+      }
+      else
+      {
+        event_log_info (hashcat_ctx, "Backend Device ID #%d", device_id + 1);
+      }
+
+      event_log_info (hashcat_ctx, "  Name...........: %s", device_name);
+      event_log_info (hashcat_ctx, "  Processor(s)...: %u", device_processors);
+      event_log_info (hashcat_ctx, "  Clock..........: %u", device_maxclock_frequency);
+      event_log_info (hashcat_ctx, "  Memory.Total...: %" PRIu64 " MB", device_global_mem / 1024 / 1024);
+      event_log_info (hashcat_ctx, "  Memory.Free....: %" PRIu64 " MB", device_available_mem / 1024 / 1024);
+      event_log_info (hashcat_ctx, "  PCI.Addr.BDFe..: %04x:%02x:%02x.%d", (u16) pcie_domain, pcie_bus, pcie_device, pcie_function);
       event_log_info (hashcat_ctx, NULL);
     }
   }
@@ -815,6 +923,24 @@ void backend_info (hashcat_ctx_t *hashcat_ctx)
         event_log_info (hashcat_ctx, "    Memory.Free....: %" PRIu64 " MB", device_available_mem / 1024 / 1024);
         event_log_info (hashcat_ctx, "    OpenCL.Version.: %s", opencl_device_c_version);
         event_log_info (hashcat_ctx, "    Driver.Version.: %s", opencl_driver_version);
+
+        if (device_param->opencl_device_type & CL_DEVICE_TYPE_GPU)
+        {
+          u8 pcie_bus      = device_param->pcie_bus;
+          u8 pcie_device   = device_param->pcie_device;
+          u8 pcie_function = device_param->pcie_function;
+
+          if ((device_param->opencl_platform_vendor_id == VENDOR_ID_AMD) && (device_param->opencl_device_vendor_id == VENDOR_ID_AMD))
+          {
+            event_log_info (hashcat_ctx, "    PCI.Addr.BDF...: %02x:%02x.%d", pcie_bus, pcie_device, pcie_function);
+          }
+
+          if ((device_param->opencl_platform_vendor_id == VENDOR_ID_NV) && (device_param->opencl_device_vendor_id == VENDOR_ID_NV))
+          {
+            event_log_info (hashcat_ctx, "    PCI.Addr.BDF...: %02x:%02x.%d", pcie_bus, pcie_device, pcie_function);
+          }
+        }
+
         event_log_info (hashcat_ctx, NULL);
       }
     }
@@ -830,6 +956,10 @@ void backend_info_compact (hashcat_ctx_t *hashcat_ctx)
   if (user_options->machine_readable == true) return;
   if (user_options->status_json      == true) return;
 
+  /**
+   * CUDA
+   */
+
   if (backend_ctx->cuda)
   {
     int cuda_devices_cnt    = backend_ctx->cuda_devices_cnt;
@@ -877,6 +1007,61 @@ void backend_info_compact (hashcat_ctx_t *hashcat_ctx)
     event_log_info (hashcat_ctx, NULL);
   }
 
+  /**
+   * HIP
+   */
+
+  if (backend_ctx->hip)
+  {
+    int hip_devices_cnt    = backend_ctx->hip_devices_cnt;
+    int hip_driver_version = backend_ctx->hip_driver_version;
+
+    const size_t len = event_log_info (hashcat_ctx, "HIP API (HIP %d.%d)", hip_driver_version / 1000, (hip_driver_version % 100) / 10);
+
+    char line[HCBUFSIZ_TINY] = { 0 };
+
+    memset (line, '=', len);
+
+    line[len] = 0;
+
+    event_log_info (hashcat_ctx, "%s", line);
+
+    for (int hip_devices_idx = 0; hip_devices_idx < hip_devices_cnt; hip_devices_idx++)
+    {
+      const int backend_devices_idx = backend_ctx->backend_device_from_hip[hip_devices_idx];
+
+      const hc_device_param_t *device_param = backend_ctx->devices_param + backend_devices_idx;
+
+      int   device_id            = device_param->device_id;
+      char *device_name          = device_param->device_name;
+      u32   device_processors    = device_param->device_processors;
+      u64   device_global_mem    = device_param->device_global_mem;
+      u64   device_available_mem = device_param->device_available_mem;
+
+      if ((device_param->skipped == false) && (device_param->skipped_warning == false))
+      {
+        event_log_info (hashcat_ctx, "* Device #%u: %s, %" PRIu64 "/%" PRIu64 " MB, %uMCU",
+                  device_id + 1,
+                  device_name,
+                  device_available_mem / 1024 / 1024,
+                  device_global_mem    / 1024 / 1024,
+                  device_processors);
+      }
+      else
+      {
+        event_log_info (hashcat_ctx, "* Device #%u: %s, skipped",
+                  device_id + 1,
+                  device_name);
+      }
+    }
+
+    event_log_info (hashcat_ctx, NULL);
+  }
+
+  /**
+   * OpenCL
+   */
+
   if (backend_ctx->ocl)
   {
     cl_uint   opencl_platforms_cnt         = backend_ctx->opencl_platforms_cnt;
@@ -1781,6 +1966,10 @@ void status_display (hashcat_ctx_t *hashcat_ctx)
 
   if (hwmon_ctx->enabled == true)
   {
+    #if defined(__APPLE__)
+    bool first_dev = true;
+    #endif
+
     for (int device_id = 0; device_id < hashcat_status->device_info_cnt; device_id++)
     {
       const device_info_t *device_info = hashcat_status->device_info_buf + device_id;
@@ -1791,6 +1980,14 @@ void status_display (hashcat_ctx_t *hashcat_ctx)
 
       if (device_info->hwmon_dev == NULL) continue;
 
+      #if defined(__APPLE__)
+      if (first_dev && strlen (device_info->hwmon_fan_dev) > 0)
+      {
+        event_log_info (hashcat_ctx, "Hardware.Mon.SMC.: %s", device_info->hwmon_fan_dev);
+        first_dev = false;
+      }
+      #endif
+
       event_log_info (hashcat_ctx,
         "Hardware.Mon.#%d..: %s", device_id + 1,
         device_info->hwmon_dev);
