@@ -191,11 +191,11 @@ static const char *const USAGE_BIG_POST_HASHMODES[] =
   "",
   "  ? | Charset",
   " ===+=========",
-  "  l | abcdefghijklmnopqrstuvwxyz",
-  "  u | ABCDEFGHIJKLMNOPQRSTUVWXYZ",
-  "  d | 0123456789",
-  "  h | 0123456789abcdef",
-  "  H | 0123456789ABCDEF",
+  "  l | abcdefghijklmnopqrstuvwxyz [a-z]",
+  "  u | ABCDEFGHIJKLMNOPQRSTUVWXYZ [A-Z]",
+  "  d | 0123456789                 [0-9]",
+  "  h | 0123456789abcdef           [0-9a-f]",
+  "  H | 0123456789ABCDEF           [0-9A-F]",
   "  s |  !\"#$%&'()*+,-./:;<=>?@[\\]^_`{|}~",
   "  a | ?l?u?d?s",
   "  b | 0x00 - 0xff",
